/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.commons.jexl.util;

import java.util.Map;

import org.apache.commons.logging.Log;


/**
 * GetExecutor that is smart about Maps. If it detects one, it does not
 * use Reflection but a cast to access the getter.
 *
 * @author <a href="mailto:henning@apache.org">Henning P. Schmiedehausen</a>
 * @version $Id$
 */
public class MapGetExecutor extends AbstractExecutor {
    private final String property;

    public MapGetExecutor(final Log rlog, final Class clazz, final String property) {
        this.rlog = rlog;
        this.property = property;
        discover(clazz);
    }

    protected void discover(final Class clazz) {
        Class[] interfaces = clazz.getInterfaces();
        for (int i = 0; i < interfaces.length; i++) {
            if (interfaces[i].equals(Map.class)) {
                try {
                    if (property != null) {
                        method = Map.class.getMethod("get", new Class[]{Object.class});
                    }
                    /**
                     * pass through application level runtime exceptions
                     */
                } catch (RuntimeException e) {
                    throw e;
                } catch (Exception e) {
                    rlog.error("While looking for get('" + property + "') method:", e);
                }
                break;
            }
        }
    }

    public Object execute(final Object o) {
        return ((Map) o).get(property);
    }
}
